@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.04';
+$VERSION = '1.05';
 
 #----------------------------------------------------------------------------
 
@@ -563,6 +563,7 @@ sub _write_basics {
     # copy files
     $self->{parent}->_log("copying static files");
     my $tocopy = $self->{parent}->tocopy;
+    $self->{parent}->_log("files to copy = " . scalar(@$tocopy));
     for my $filename (@$tocopy) {
         my $source = $templates . "/$filename";
         if(-f $source) {
@@ -571,11 +572,14 @@ sub _write_basics {
 
             mkpath( dirname($target) );
             if(-d dirname($target)) {
+                $self->{parent}->_log("copying '$source' to '$target'");
                 copy( $source, $target );
             } else {
+                $self->{parent}->_log("copy error: Missing directory: $target");
                 warn "Missing directory: $target\n";
             }
         } else {
+            $self->{parent}->_log("copy error: Missing file: $source");
             warn "Missing file: $source\n";
         }
     }
@@ -597,6 +601,7 @@ sub _write_basics {
 
     # wget
     my $cmd = sprintf "wget -O %s/sponsors.json http://iheart.cpantesters.org/home/sponsors?images=1 2>/dev/null", $directory;
+    $self->{parent}->_log("sponsors: '$cmd'");
     system($cmd);
 }
 
